@@ -29,7 +29,9 @@
 
 void p_entry_col(entry_col *ecp)
 {
-    printf("%.*s", ecp->ec_value.ec_value_len, ecp->ec_value.ec_value_val);
+    printf("%.*s",
+	   (int) ecp->ec_value.ec_value_len,
+	   ecp->ec_value.ec_value_val);
 }
 
 
@@ -47,9 +49,9 @@ void p_entry(entry_obj *eop, int sep)
     putchar('\n');
 }
 
+extern void print_result(nis_result *, int);
 
-
-main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
     nis_result *nsres;
     int separator;
