@@ -26,9 +26,9 @@
 #include <stdio.h>
 #include <rpcsvc/nis.h>
 
+extern void print_result(nis_result *, int);
 
-
-main(argc,argv)
+int main(argc,argv)
     int argc;
     char *argv[];
 {
